==> pipewire-docs-1%3A0.3.30-2-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/mem_8c.js <==
var mem_8c =
[
    [ "mempool", "structmempool.html", "structmempool" ],
    [ "memblock", "structmemblock.html", "structmemblock" ],
    [ "mapping", "structmapping.html", "structmapping" ],
    [ "memmap", "structmemmap.html", "structmemmap" ],
    [ "F_ADD_SEALS", "mem_8c.html#a3c9cb62957637bb3b3a869cbbe5e4aaa", null ],
    [ "F_GET_SEALS", "mem_8c.html#a0d7e40a9933d11da2fc1b0b1b863eec3", null ],
    [ "F_LINUX_SPECIFIC_BASE", "mem_8c.html#a54af789ad65b83449d415dbfb7d39481", null ],
    [ "F_SEAL_GROW", "mem_8c.html#a6ae683cd27bb82613d1c025277b69b48", null ],
    [ "F_SEAL_SEAL", "mem_8c.html#a68a01fe6f7305883d5f15ddfd1ebfd84", null ],
    [ "F_SEAL_SHRINK", "mem_8c.html#a98ea0829a6ae8b9adb9910457f4ca4cd", null ],
    [ "F_SEAL_WRITE", "mem_8c.html#a82af8008b212e99dd3a8b8daa2138170", null ],
    [ "HAVE_MEMFD_CREATE", "mem_8c.html#a3f4ae88428cbac5a85c1ef40b0e6b7f7", null ],
    [ "MFD_ALLOW_SEALING", "mem_8c.html#a1d9ebf7ab094a827cd93d1e49e81e8a0", null ],
    [ "MFD_CLOEXEC", "mem_8c.html#a3268e6d65db2950f67f6082946d16952", null ],
    [ "NAME", "mem_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
    [ "pw_mempool_emit", "mem_8c.html#aee8f104fd65b3d11fef242883a787657", null ],
    [ "pw_mempool_emit_added", "mem_8c.html#ad2d67640ddabf8a7f530053ebca34abf", null ],
    [ "pw_mempool_emit_destroy", "mem_8c.html#ad9bd7205a3e7a88320624ef7addbfe9f", null ],
    [ "pw_mempool_emit_removed", "mem_8c.html#a1eac736570d41ffac78ec7c5caa8ca25", null ],
    [ "pw_memblock_map", "group__pw__memblock.html#ga129ecc0ee25039116cc99c138e16c4c6", null ],
    [ "pw_memmap_free", "group__pw__memblock.html#ga3efb664909dd90a771d5092238a7a603", null ],
    [ "pw_mempool_add_listener", "group__pw__memblock.html#ga5c298052be6fe8f5f4ea78b4fe41733d", null ],
    [ "pw_mempool_clear", "group__pw__memblock.html#ga9e39d964e7ba4d39449cb8b569504a3e", null ],
    [ "pw_mempool_destroy", "group__pw__memblock.html#gab253128cb2d2bc7ad5203d2b65e762c8", null ],
    [ "pw_mempool_find_fd", "group__pw__memblock.html#gadc0de7b22a2892cdf9582fbcf6f4b712", null ],
    [ "pw_mempool_find_id", "group__pw__memblock.html#ga8cefbc9877517111668c36f24edb2dfd", null ],
    [ "pw_mempool_find_ptr", "group__pw__memblock.html#ga637115c056f47906c4d52faf043e415f", null ],
    [ "pw_mempool_find_tag", "group__pw__memblock.html#gaf11ea8ae8c13e394c39d7bf035be4f7b", null ],
    [ "pw_mempool_import", "group__pw__memblock.html#gacc1fb3bb1d96fa7ee1b6850eb865ebe6", null ],
    [ "pw_mempool_import_block", "group__pw__memblock.html#ga40f7779f907ebc367725ba5c7c8b0f88", null ],
    [ "pw_mempool_import_map", "group__pw__memblock.html#ga85ef7c8290e81beb53ab9e1c7b44ff29", null ],
    [ "pw_mempool_map_id", "group__pw__memblock.html#gaa9b5475f99e223a1b20d1d1b79549381", null ],
    [ "pw_mempool_new", "group__pw__memblock.html#gae5e42242439fef39fd696db151642513", null ],
    [ "pw_mempool_remove_id", "group__pw__memblock.html#ga4795146fb79f58f2277d535f71bdea34", null ]
];

==> pipewire-docs-1%3A0.3.38-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/mem_8c.js <==
var mem_8c =
[
    [ "mempool", "structmempool.html", "structmempool" ],
    [ "memblock", "structmemblock.html", "structmemblock" ],
    [ "mapping", "structmapping.html", "structmapping" ],
    [ "memmap", "structmemmap.html", "structmemmap" ],
    [ "F_ADD_SEALS", "mem_8c.html#a3c9cb62957637bb3b3a869cbbe5e4aaa", null ],
    [ "F_GET_SEALS", "mem_8c.html#a0d7e40a9933d11da2fc1b0b1b863eec3", null ],
    [ "F_LINUX_SPECIFIC_BASE", "mem_8c.html#a54af789ad65b83449d415dbfb7d39481", null ],
    [ "F_SEAL_GROW", "mem_8c.html#a6ae683cd27bb82613d1c025277b69b48", null ],
    [ "F_SEAL_SEAL", "mem_8c.html#a68a01fe6f7305883d5f15ddfd1ebfd84", null ],
    [ "F_SEAL_SHRINK", "mem_8c.html#a98ea0829a6ae8b9adb9910457f4ca4cd", null ],
    [ "F_SEAL_WRITE", "mem_8c.html#a82af8008b212e99dd3a8b8daa2138170", null ],
    [ "HAVE_MEMFD_CREATE", "mem_8c.html#a3f4ae88428cbac5a85c1ef40b0e6b7f7", null ],
    [ "MFD_ALLOW_SEALING", "mem_8c.html#a1d9ebf7ab094a827cd93d1e49e81e8a0", null ],
    [ "MFD_CLOEXEC", "mem_8c.html#a3268e6d65db2950f67f6082946d16952", null ],
    [ "NAME", "mem_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
    [ "pw_mempool_emit", "mem_8c.html#aee8f104fd65b3d11fef242883a787657", null ],
    [ "pw_mempool_emit_added", "mem_8c.html#ad2d67640ddabf8a7f530053ebca34abf", null ],
    [ "pw_mempool_emit_destroy", "mem_8c.html#ad9bd7205a3e7a88320624ef7addbfe9f", null ],
    [ "pw_mempool_emit_removed", "mem_8c.html#a1eac736570d41ffac78ec7c5caa8ca25", null ],
    [ "pw_memblock_free", "group__pw__memblock.html#gaa706ad494480f45ba0683ee91b2779d1", null ],
    [ "pw_memblock_map", "group__pw__memblock.html#gab6f8173f833296d33affcb86ae785316", null ],
    [ "pw_memmap_free", "group__pw__memblock.html#ga3efb664909dd90a771d5092238a7a603", null ],
    [ "pw_mempool_add_listener", "group__pw__memblock.html#ga5c298052be6fe8f5f4ea78b4fe41733d", null ],
    [ "pw_mempool_alloc", "group__pw__memblock.html#ga27f6b0a11cef5a49cde3fab1ae642491", null ],
    [ "pw_mempool_clear", "group__pw__memblock.html#ga9e39d964e7ba4d39449cb8b569504a3e", null ],
    [ "pw_mempool_destroy", "group__pw__memblock.html#gab253128cb2d2bc7ad5203d2b65e762c8", null ],
    [ "pw_mempool_find_fd", "group__pw__memblock.html#ga7c9a4b5c0796b52a4519b4f7c3cc301a", null ],
    [ "pw_mempool_find_id", "group__pw__memblock.html#ga92dbc7bc8f980e8cb518b7feac01df3e", null ],
    [ "pw_mempool_find_ptr", "group__pw__memblock.html#ga9d39624b18e771eb7184bfd75c226be0", null ],
    [ "pw_mempool_find_tag", "group__pw__memblock.html#ga080fb17973757073bf92c72fc4e6f8d1", null ],
    [ "pw_mempool_import", "group__pw__memblock.html#ga134aecacce3f6357cb0ca6bf9bd36b47", null ],
    [ "pw_mempool_import_block", "group__pw__memblock.html#ga4acd2b36bdd50840f84e9ec5d2feef49", null ],
    [ "pw_mempool_import_map", "group__pw__memblock.html#ga6d778c718234eda39ea5632bffa40162", null ],
    [ "pw_mempool_map_id", "group__pw__memblock.html#ga5c3422b17f5f4bae75efe0603fde6150", null ],
    [ "pw_mempool_new", "group__pw__memblock.html#ga2ac4c816115d56d320c868171597f640", null ],
    [ "pw_mempool_remove_id", "group__pw__memblock.html#ga4795146fb79f58f2277d535f71bdea34", null ]
];
